@@ -1104,7 +1104,7 @@ class ValiotWorker():
             queue_name = __.get(shedeuleQueue, 'name', None)
             if queue_name:
                 self.continuousJobs.append(queue_name)
-                queueLocks, errors = self.gql.query_one(queries.get_queueLocks, variables={
+                queueLocks, errors = self.gql.query(queries.get_queueLocks, variables={
                     "workerCode": self.worker_code, "queueName": queue_name})
                 if errors:
                     self.log(LogLevel.ERROR,
@@ -1113,16 +1113,17 @@ class ValiotWorker():
                 if queueLocks:
                     self.log(
                         LogLevel.WARNING, f'{queue_name} queue (CONTINUOUS type) has queueLocks')
-                    variables = {
-                        'id': __.get(queueLocks, 'id', None),
-                        'active': False,
-                        'endAt': getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
-                    }
-                    _, errors = self.gql.mutate(
-                        mutations.update_lock, variables)
-                    if errors:
-                        self.log(LogLevel.ERROR,
-                                 f'Error update_lock:\n{errors}')
+                    for queueLock in queueLocks:
+                        variables = {
+                            'id': __.get(queueLock, 'id', None),
+                            'active': False,
+                            'endAt': getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
+                        }
+                        _, errors = self.gql.mutate(
+                            mutations.update_lock, variables)
+                        if errors:
+                            self.log(LogLevel.ERROR,
+                                    f'Error update_lock:\n{errors}')
 
         if self.continuousJobs:
             self.log(LogLevel.SUCCESS, 'REGISTERED Continuous Queues:')
